@@ -17,10 +17,10 @@
             The University of Chicago
 """
 
-from .asteval import Interpreter
-from .astutils import (NameFinder, valid_symbol_name, make_symbol_table,
-                       get_ast_names)
 from ._version import get_versions
+from .asteval import Interpreter
+from .astutils import (NameFinder, get_ast_names, make_symbol_table,
+                       valid_symbol_name)
 
 __all__ = ['Interpreter', 'NameFinder', 'valid_symbol_name',
            'make_symbol_table', 'get_ast_names']
